Dissimilarity-based analysis functions including ordination and Mantel test functions, intended for use with spatial and community data.
This package contains well-established dissimilarity-based ecological analyses, such as nmds and mantel, and experimental/research analyses such as xmantel. Helper functions such as crosstab and cor2m facilitate analysis of community data.
Because many of the analyses are time-consuming, this package includes worked examples that can be loaded using data().
ecodist